@@ -15,6 +15,7 @@
 
 #include "compiler/compiler.h"
 #include "list.h"
+#include "fifo.h"
 #include "rbtree.h"
 #include "md5.h"
 #include "crc32.h"
@@ -88,6 +89,7 @@ struct io_piece {
 	unsigned long long offset;
 	unsigned long len;
 	enum fio_ddir ddir;
+	unsigned long delay;
 };
 
 #ifdef FIO_HAVE_SYSLET
@@ -266,6 +268,7 @@ struct fio_file {
 	 */
 	char *file_name;
 	void *mmap;
+	unsigned int major, minor;
 
 	/*
 	 * size of the file, offset into file, and io size from that offset
@@ -391,7 +394,7 @@ struct thread_options {
 	unsigned int thinktime_blocks;
 	unsigned int fsync_blocks;
 	unsigned int start_delay;
-	unsigned long timeout;
+	unsigned long long timeout;
 	unsigned int overwrite;
 	unsigned int bw_avg_time;
 	unsigned int loops;
@@ -403,6 +406,7 @@ struct thread_options {
 	unsigned int new_group;
 	unsigned int numjobs;
 	os_cpu_mask_t cpumask;
+	unsigned int cpumask_set;
 	unsigned int iolog;
 	unsigned int rwmixcycle;
 	unsigned int rwmix[2];
@@ -521,6 +525,7 @@ struct thread_data {
 	struct timeval start;	/* start of this loop */
 	struct timeval epoch;	/* time job was started */
 	struct timeval rw_end[2];
+	struct timeval last_issue;
 	unsigned int rw_end_set[2];
 
 	/*
@@ -663,13 +668,6 @@ struct disk_util {
 
 #define DISK_UTIL_MSEC	(250)
 
-#ifndef min
-#define min(a, b)	((a) < (b) ? (a) : (b))
-#endif
-#ifndef max
-#define max(a, b)	((a) > (b) ? (a) : (b))
-#endif
-
 /*
  * Log exports
  */
@@ -825,6 +823,14 @@ extern int __must_check td_io_commit(struct thread_data *);
 extern int __must_check td_io_open_file(struct thread_data *, struct fio_file *);
 extern void td_io_close_file(struct thread_data *, struct fio_file *);
 
+/*
+ * blktrace support
+ */
+#ifdef FIO_HAVE_BLKTRACE
+extern int is_blktrace(const char *);
+extern int load_blktrace(struct thread_data *, const char *);
+#endif
+
 /*
  * If logging output to a file, stderr should go to both stderr and f_err
  */
